import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

public class Ball extends Actor
{
    private static final Color MAIN_COLOR = Color.cyan;
    private static final Color UPGR_COLOR = Color.black;

    private static boolean paused, mute;
    private boolean released, upgraded, sticky, normalize;
    private int difficulty, deltaX, deltaY, count, enlarge, shrink;
    
    public static void pause() {
        paused = !paused;
    }

    public Ball(int pDifficulty) {
        difficulty = pDifficulty;
        updateImage(12, 12, Color.cyan);
    }
    
    public static void muteSound() {
        mute = !mute;
    }
    
    private void updateImage(int width, int height, Color c) {
        GreenfootImage img = new GreenfootImage(width, height);
        img.setColor(c);
        img.fillOval(0, 0, width-1, height-1);
        img.setColor(Color.white);
        img.drawOval(0, 0, width-1, height-1);
        setImage(img);
    } 
    
    public void act() {
        if(released && !paused) {
            if(enlarge > -1) {
                updateImage(getImage().getWidth()+1, getImage().getHeight()+1);
                enlarge++;
                if(enlarge > 3) {  enlarge = -1;  }            
            }
            if(shrink > -1) {
                updateImage(getImage().getWidth()-1, getImage().getHeight()-1);
                shrink++;
                if(shrink > 3)  {  shrink = -1;   }            
            }
            if(normalize) {
                if(getImage().getWidth() < 12) {  updateImage(getImage().getWidth()+1, getImage().getHeight()+1);  }
                if(getImage().getWidth() > 12) {  updateImage(getImage().getWidth()-1, getImage().getHeight()-1);  }
                if(getImage().getWidth() == 12){
                    updateImage(getImage().getWidth(), getImage().getHeight());
                    normalize = false;
                }
            }
            move();
            checkWalls();     
            checkNet();
            checkPaddle();
            checkBrick();
            checkOut();
        }
    }
    
    public void release() {
        deltaX = Greenfoot.getRandomNumber(11) - 5;
        deltaY = -5;
        released = true;
    }
    
    private void move() {
        if(deltaX > difficulty)  {  deltaX = difficulty;   }
        if(deltaX < -difficulty) {  deltaX = -difficulty;  }
        if(deltaY > difficulty)  {  deltaY = difficulty;   }
        if(deltaY < -difficulty) {  deltaY = -difficulty;  }
        setLocation (getX() + deltaX, getY() + deltaY);
        if(getX() <= 0) {  setLocation(getX() + getImage().getWidth(), getY());  }
        if(getX() >= getWorld().getWidth()-140) {  setLocation(getX() - getImage().getWidth(), getY());  }
        if(getY() <= 0) {  setLocation(getX(), getY() + getImage().getHeight());  }        
    }
    
    private void checkWalls() {
        if((deltaX < 0 && getX() < getImage().getWidth()) || (deltaX > 0 && getX() >= getWorld().getWidth()-140-getImage().getWidth())) { 
            if(!mute) { Greenfoot.playSound("sounds/cling_1.wav"); }
            deltaX = -deltaX; 
        } 
        if(deltaY < 0 && getY() <= getImage().getHeight()/2) { 
            if(!mute) { Greenfoot.playSound("sounds/cling_1.wav"); }
            deltaY = -deltaY; 
        }
    }   
    
    private void checkNet() {
        Actor net = getOneIntersectingObject(Net.class);
        if (net != null) {
            deltaY = -deltaY;
            getWorld().removeObject(net);
        }            
    }
    
    private void checkOut() {
        if(getY() > getWorld().getHeight()-10) {
            ((Board) getWorld()).ballIsOut(this);
        }
    }
    
    private void checkPaddle() {
        Paddle paddle = (Paddle) getOneIntersectingObject(Paddle.class);
        if(paddle != null) {
            ((Board) getWorld()).score(10);
            if(!mute) { Greenfoot.playSound("sounds/cling_1.wav"); }
            if(!sticky) {  bounce(paddle);   }
            else        {  
                released = false; 
                paddle.setBall(this); 
            }
        }            
    }
    
    private void checkBrick() {
        Brick brick = (Brick) getOneIntersectingObject(Brick.class);
        if(brick != null) {
            if(brick.isDestroyable()) {  ((Board) getWorld()).score(50);  }
            if(upgraded && brick.isDestroyable()) {  brick.remove();  }              
            else {
                if(!mute) { Greenfoot.playSound("sounds/cling_2.wav"); }
                bounce(brick);
                brick.hit();
                count++;
                int rand = Greenfoot.getRandomNumber(500)+1;
                if(rand > 0) {
                    if(count % rand == 0) {
                        deltaX += 2;
                    }
                }
            }         
        }
    }
    
    private void bounce(Actor a) {
        deltaY = -deltaY;
        int offset = getX()-a.getX();
        deltaX = deltaX+(offset/10);
    }     
    
    public void upgrade() {
        upgraded = true;
        sticky = false;
        normalize = true;
    }
    
    public void downgrade() {
        upgraded = false;
        normalize = true;
        sticky = false;
    }
    
    public void enlarge() {
        upgraded = false;
        sticky = false;
        if(getImage().getWidth() < 24) {  enlarge = 0;  }
    }
    
    public void shrink() {
        upgraded = false;
        sticky = false;
        if(getImage().getWidth() > 6)  {  shrink = 0;   }
    }
    
    public void sticky() {
        sticky = true;
        upgraded = false;
        normalize = true;
    }
    
    public void unsticky() {
        sticky = false;
    }
    
    private void updateImage(int width, int height) {
        GreenfootImage img = new GreenfootImage(width, height);
        if(upgraded) {  img.setColor(UPGR_COLOR);  }
        else         {  img.setColor(MAIN_COLOR);  }
        img.fillOval(0, 0, width-1, height-1);
        img.setColor(Color.white);
        img.drawOval(0, 0, width-1, height-1);
        setImage(img);
    }
}