import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

public class Brick extends Actor
{
    public class Shadow extends Actor
    {   
        public Shadow() {
            GreenfootImage img = new GreenfootImage(46, 21);
            img.setColor(Color.black);
            img.fill();
            img.setTransparency(90);
            setImage(img);
        }
    }
    
    private Item[] items = { new Item(Item.ENLPAD), new Item(Item.SHRPAD), new Item(Item.SHOOTPAD), new Item(Item.ENLBALL), new Item(Item.SHRBALL), new Item(Item.UPGRBALL), new Item(Item.STICKYBALL), new Item(Item.NET), new Item(Item.PPOINTS), new Item(Item.MPOINTS), new Item(Item.LIFE), new Item(Item.DEATH) };
    protected Color color;
    protected char literal;
    protected int width, height, hits, animate;
    protected boolean destroyable;
    private Shadow shadow;
    private static boolean paused;
    
    public static void pause() {
        paused = !paused;
    }
    
    public Brick(Color pColor, char pLiteral) {
        this(pColor, 1, true, pLiteral);
    }
    
    public Brick(Color pColor, int pHits, boolean pDestroyable, char pLiteral) {
        color = pColor;
        hits = pHits;
        destroyable = pDestroyable;
        literal = pLiteral;
        width = 46;
        height = 21;
        updateImage(color);
    }
    
    protected void updateImage(Color pColor) {
        GreenfootImage img = new GreenfootImage(width, height);
        img.setColor(pColor);
        img.fill();
        img.setColor(pColor.darker());
        img.drawRect(0, 0, img.getWidth(), img.getHeight());
        img.drawRect(1, 1, img.getWidth(), img.getHeight());
        img.setColor(pColor.darker().darker());
        img.fillRect(0, img.getHeight()-3, img.getWidth(), 3);
        img.fillRect(img.getWidth()-3, 0, 3, img.getHeight());
        setImage(img);
    }
    
    public void addedToWorld(World pWorld) {
        shadow = new Shadow();
        if(getWorld().getObjects(EditorBrick.class).isEmpty()) {
            pWorld.addObject(shadow, getX()+15, getY()+15);
        }
    }
    
    public void act() {
        if(animate > -1) {
            animate++;
            if(animate == 7) {
                updateImage(color);
                animate = -1;
            }
        }
        if(!getWorld().getObjects(EditorBrick.class).isEmpty()) {
            if(Greenfoot.mouseClicked(this)) {
                getWorld().addObject(new GridCell(), getX(), getY());
                getWorld().removeObject(shadow);
                getWorld().removeObject(this);           
            }
        }
    }
    
    public void hit() {
        if(destroyable) {
            hits--;
            if(hits == 0) {
                remove();
            }
        }
        getImage().setColor(Color.white);
        getImage().fill();
        animate = 0;
    }
    
    public void remove() {
        bonus();
        getWorld().removeObject(shadow);
        getWorld().removeObject(this);
    }
    
    public boolean isDestroyable() {
        return destroyable;
    }
    
    public char getLiteral() {
        return literal;
    }
    
    private void bonus() {
        int random = Greenfoot.getRandomNumber(25);
        if(random == 3) {
            int i = Greenfoot.getRandomNumber(items.length);
            getWorld().addObject(items[i], getX(), getY());
        }
    }
}