import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.*;

public class Item extends Actor
{
    public static final GreenfootImage ENLPAD = new GreenfootImage("images/items/enl_pad.png");
    public static final GreenfootImage SHRPAD = new GreenfootImage("images/items/shr_pad.png");
    public static final GreenfootImage SHOOTPAD = new GreenfootImage("images/items/shoot.png");
    public static final GreenfootImage ENLBALL = new GreenfootImage("images/items/enl_ball.png");
    public static final GreenfootImage SHRBALL = new GreenfootImage("images/items/shr_ball.png");
    public static final GreenfootImage UPGRBALL = new GreenfootImage("images/items/upgr_ball.png");
    public static final GreenfootImage STICKYBALL = new GreenfootImage("images/items/sticky_ball.png");
    public static final GreenfootImage NET = new GreenfootImage("images/items/rescue.png");
    public static final GreenfootImage PPOINTS = new GreenfootImage("images/items/extra_points.png");
    public static final GreenfootImage MPOINTS = new GreenfootImage("images/items/minus_points.png");
    public static final GreenfootImage LIFE = new GreenfootImage("images/items/life.png");
    public static final GreenfootImage DEATH = new GreenfootImage("images/items/death.png");

    private static boolean paused;
    
    private Board world;
    private Ball ball;
    
    private GreenfootImage img;
    private boolean move = true;
    
    public static void pause() {
        paused = !paused;
    }
    
    public Item(GreenfootImage img) {
        setImage(img);
    }
    
    public void addedToWorld(World pWorld) {
        world = (Board) pWorld;
        ball = world.getBall();
    }
    
    public void act() {
        Paddle paddle = (Paddle) getOneIntersectingObject(Paddle.class);
        if(paddle != null) {
            bonus(paddle);
            move = false;
            world.removeObject(this);
        }
        if(move && !paused) {  fall();  }
    }
    
    private void fall() {
        if(getY() < getWorld().getHeight()-10)  {  setLocation(getX(), getY()+3);  }
        else {  getWorld().removeObject(this);  }
    }
    
    private void bonus(Paddle pPaddle) {
        if(getImage().equals(ENLPAD)) {
            pPaddle.enlarge();
            world.score(25);
        }
        else if(getImage().equals(SHRPAD)) {
            pPaddle.shrink();
            ball.downgrade();
            world.score(-25);
        }
        else if(getImage().equals(SHOOTPAD)) {
            pPaddle.shoot();
            ball.downgrade();
            world.score(25);
        }
        else if(getImage().equals(ENLBALL)) {
            ball.enlarge();
            pPaddle.normalize();
            world.score(25);
        }
        else if(getImage().equals(SHRBALL)) {
            ball.shrink();
            world.score(-25);
        }
        else if(getImage().equals(UPGRBALL)) {
            ball.upgrade();
            pPaddle.normalize();
            world.score(25);
        }
        else if(getImage().equals(STICKYBALL)) {
            ball.sticky();
            pPaddle.normalize();
            world.score(-25);
        }
        else if(getImage().equals(NET)) {
            pPaddle.normalize();
            ball.downgrade();
            world.addObject(new Net(), 230, pPaddle.getY());
            world.score(25);
        }
        else if(getImage().equals(PPOINTS)) {
            world.score(500);
        }
        else if(getImage().equals(MPOINTS)) {
            world.score(-500);
        }
        else if(getImage().equals(LIFE)) {
            world.life(1);
            world.score(25);
        }
        else if(getImage().equals(DEATH)) {
            world.ballIsOut(null);
            world.score(-25);
        }
    }
}