import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
import javax.swing.*;

public class Menu extends Actor
{
    private Board world;

    private boolean editor, multiplayer, mouseControl;
    private int difficulty, level;
    
    public void addedToWorld(World pWorld) {
        world = (Board) pWorld;    
        String[] labels = { "Play", "Create own", "Go To" };
        goFurther(labels);
    }
    
    public void setEditor(boolean pEditor) {
        editor = pEditor;
        if(!editor) {
            String[] labels = { "Use mouse", "Use keyboard" };
            goFurther(labels);
        }            
        else {
            world.levelEditor();
        }
    }
    
    public void setLevel(int pLevel) {
        level = pLevel;
        setEditor(false);
    }
        
    
    public void setMouseControl(boolean pMouseControl) {
        mouseControl = pMouseControl;
        String[] labels = { "Single player", "Multiplayer" };
        goFurther(labels);
    }

    public void setMultiplayer(boolean pMultiplayer) {
        multiplayer = pMultiplayer;
        String[] labels = { "Easy", "Medium", "Hard" };
        goFurther(labels);
    }
    
    public void setDifficulty(int pDifficulty) {
        difficulty = pDifficulty;
        if(level <= 0) {
            world.start(mouseControl, multiplayer, difficulty);
        }
        else {
            world.jumpToLevel(level, mouseControl, multiplayer, difficulty);
        }
    }
    
    private void goFurther(String[] labels) {
        world.removeObjects(world.getObjects(MenuButton.class));
        for(int i=0; i < labels.length; i++) {
            world.addObject(new MenuButton(labels[i], this), world.getWidth()/2, 150*(i+1));
        }
    }
    
    public class MenuButton extends Actor
    {
        public Menu menu;
        private String txt;
    
        public MenuButton(String pTxt, Menu pMenu) {
           menu = pMenu;
           txt = pTxt;
           GreenfootImage img = new GreenfootImage("images/button.png");
           img.setColor(Color.white);
           img.drawString(txt, img.getWidth()/2-txt.length()*3, img.getHeight()/2+4);
           setImage(img);
        } 
        
        public void act() {
            if(Greenfoot.mouseClicked(this)) {
                if(txt.equals("Play")) {
                    menu.setEditor(false);        
                }
                else if(txt.equals("Create own")) {
                    menu.setEditor(true);
                }
                else if(txt.equals("Go To")) {
                    String pwd = (String) JOptionPane.showInputDialog(null, "Please enter password to jump to the desired level!");
                    if(world.passwordExists(pwd) && pwd != null) {  menu.setLevel(world.getLevel(pwd));  }
                    else {  JOptionPane.showMessageDialog(null, "Cannot find level!");  }                                             
                }
                else if(txt.equals("Use mouse")) {
                    menu.setMouseControl(true);
                }
                else if(txt.equals("Use keyboard")) {
                    menu.setMouseControl(false);
                }
                else if(txt.equals("Single player")) {
                    menu.setMultiplayer(false);
                }
                else if(txt.equals("Multiplayer")) {
                    menu.setMultiplayer(true);
                }
                else if(txt.equals("Easy")) {
                    menu.setDifficulty(3);
                }
                else if(txt.equals("Medium")) {
                    menu.setDifficulty(6);
                }
                else if(txt.equals("Hard")) {
                    menu.setDifficulty(9);
                }
            }
        }
    }
}