import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

public class Paddle extends Actor
{
    private static boolean paused;
    private Ball myBall;
    private boolean followMouse, addBall, normalize, shoot, fired;
    private int difficulty, enlarge, shrink;
    
    public static void pause() {
        paused = !paused;
    }
    
    public Paddle(boolean pFollowMouse, boolean pAddBall, int pDifficulty) {
        followMouse = pFollowMouse;
        addBall = pAddBall;
        difficulty = pDifficulty;
        enlarge = -1;
        shrink = -1;
    }
    
    public void addedToWorld(World world) {
        if(addBall) {  newBall();  }
    }
    
    public void newBall() {
        normalize();
        myBall = new Ball(difficulty);
        ((Board) getWorld()).setBall(myBall);
        getWorld().addObject(myBall, getX(), getY()-15);
    }
    
    public void act() {
        if(!paused) {
            int dist = 0;
            if(!followMouse) {  
                if(Greenfoot.isKeyDown("left")) {
                    dist = -9;
                }
                if(Greenfoot.isKeyDown("right")) {
                    dist = 9;
                }
            }
            else { 
                if(Greenfoot.mouseMoved(null)) {
                    MouseInfo mouse = Greenfoot.getMouseInfo();
                    dist = mouse.getX() - getX();
                }
            }
            move(dist);
            if(myBall != null) {
                if(Greenfoot.isKeyDown("space") || (Greenfoot.mouseClicked(null) && followMouse)) {
                    myBall.release();
                    myBall = null;
                }
            }
            else if(shoot && getWorld().getObjects(Projectile.class).size() < 6) {
                if((Greenfoot.isKeyDown("space") && !fired) || (Greenfoot.mouseClicked(null) && followMouse)) {
                    getWorld().addObject(new Projectile(), getX()+getImage().getWidth()/2-23, getY()-getImage().getHeight()/2);
                    getWorld().addObject(new Projectile(), getX()-getImage().getWidth()/2-23, getY()-getImage().getHeight()/2);
                    fired = true;
                }
                else if(!Greenfoot.isKeyDown("space") && fired) {  fired = false;  }
            }
            if(enlarge > -1) {
                updateImage(getImage().getWidth()+1);
                enlarge++;
                if(enlarge > 25) {  enlarge = -1;  }            
            }
            if(shrink > -1) {
                updateImage(getImage().getWidth()-1);
                shrink++;
                if(shrink > 25)  {  shrink = -1;   }            
            }
            if(normalize) {
                if(getImage().getWidth() < 100)  {  updateImage(getImage().getWidth()+1);  }
                if(getImage().getWidth() > 100)  {  updateImage(getImage().getWidth()-1);  }
                if(getImage().getWidth() == 100) {  normalize = false;                     }
            }
        }
    }
    
    public void move(int dist) {
        if(getX()+dist >= getImage().getWidth()/2 && getX()+dist <= getWorld().getWidth()-140-getImage().getWidth()/2) {
            setLocation(getX() + dist, getY());
            if(myBall != null) {  myBall.move(dist);  }
        }
    }        
    
    public void shoot() {
        shoot = true;
        setImage("images/paddle_s.png");
    }
    
    public void enlarge() {
        if(getImage().getWidth() < 175) {  enlarge = 0;  }
    }
    
    public void shrink() {
        if(getImage().getWidth() > 50)  {  shrink = 0;   }
    }
    
    public void normalize() {
        if(shoot) {
            shoot = false;
            setImage("images/paddle.png");
        }
        normalize = true;
    }
    
    public void setBall(Ball pBall) {
        myBall = pBall;
    }
    
    private void updateImage(int width) {
        if(shoot) {
            shoot = !shoot;
            setImage("images/paddle.png");
        }
        getImage().scale(width, getImage().getHeight());
        if(getX()+9 < getImage().getWidth()/2) { setLocation(getImage().getWidth()/2, getY()); }
        if(getX()-9 > getWorld().getWidth()-140-getImage().getWidth()/2) { setLocation(getWorld().getWidth()-140-getImage().getWidth()/2, getY()); }
    }
}